@@ -1,8 +1,9 @@
 package App::bmkpasswd;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use strict;
 use warnings;
+use Carp;
 
 use Crypt::Eksblowfish::Bcrypt qw/bcrypt en_base64/;
 
@@ -13,7 +14,7 @@ our @EXPORT_OK = qw/
   passwdcmp
 /;
 
-our $HAVE_PASSWD_XS = 0;
+our $HAVE_PASSWD_XS;
 
 sub mkpasswd {
   my ($pwd, $type, $cost) = @_;
@@ -22,7 +23,7 @@ sub mkpasswd {
   
   # a default (randomized) salt
   # can be used for md5 or built on for SHA
-  my @p = ( 'a' .. 'z', 'A' .. 'Z', 0 .. 9 );
+  my @p = ( 'a' .. 'z', 'A' .. 'Z', 0 .. 9, '.', '/' );
   my $salt = join '', map { $p[rand@p] } 1 .. 8;
   
   TYPE: {
@@ -38,7 +39,7 @@ sub mkpasswd {
     # Not sure of other libcs with support.
     # Ulrich Drepper's been evangelizing a bit . . .
     if ($type =~ /sha-?512/i) {
-      die "SHA hash requested but no SHA support available\n" 
+      croak "SHA hash requested but no SHA support available" 
         unless have_sha(512);
       # SHA has variable length salts (max 16)
       # Drepper claims this can slow down attacks.
@@ -49,7 +50,7 @@ sub mkpasswd {
     }
     
     if ($type =~ /sha(-?256)?/i) {
-      die "SHA hash requested but no SHA support available\n" 
+      croak "SHA hash requested but no SHA support available" 
         unless have_sha(256);
       $salt .= $p[rand@p] for 1 .. rand 8;
       $salt = '$5$'.$salt.'$';
@@ -70,7 +71,7 @@ sub mkpasswd {
     if ( eval { require Crypt::Passwd::XS } && !$@) {
       return Crypt::Passwd::XS::crypt($pwd, $salt);
     } else {
-      die "\$HAVE_PASSWD_XS=1 but Crypt::Passwd::XS not loadable\n";
+      croak "\$HAVE_PASSWD_XS=1 but Crypt::Passwd::XS not loadable";
     }
   } else {
     return crypt($pwd, $salt);  
